=============
Release Notes
=============

Viziphant 0.2.0 release notes
*****************************

Documentation
-------------
* Documentation revised in style, logo was added

New functionality and features
------------------------------
* New `patterns` module to display spike patterns by elephant modules, such as SPADE or CAD (https://github.com/INM-6/viziphant/pull/35)
* New function to display the spike contrast measure (https://github.com/INM-6/viziphant/pull/34)
* Added function to display rate trajectories plotted by the GPFA module (https://github.com/INM-6/viziphant/pull/37)

Bug fixes
---------
* Bug fixes for the ISI and Unitary Event plots (https://github.com/INM-6/viziphant/pull/31) and (https://github.com/INM-6/viziphant/pull/32).

Miscellaneous
-------------
* Continuous Integration (CI) was moved to github actions (https://github.com/INM-6/viziphant/pull/41)

Selected dependency changes
---------------------------
* `elephant>=0.9.0`


Viziphant 0.1.0 release notes
*****************************

This release constitutes the initial Viziphant release.
